==> haskell-skein-1.0.9.4-10-i686.pkg.tar.xz: usr/share/haskell/register/haskell-skein.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skein
version: 1.0.9.4
id: skein-1.0.9.4-GSelp4WxinFGAQx3fUyVRc
key: skein-1.0.9.4-GSelp4WxinFGAQx3fUyVRc
license: BSD3
maintainer: Felipe Lessa <felipe.lessa@gmail.com>
homepage: https://github.com/meteficha/skein
synopsis: Skein, a family of cryptographic hash functions.  Includes Skein-MAC as well.
description:
    Skein (<http://www.skein-hash.info/>) is a family of fast
    secure cryptographic hash functions designed by Niels
    Ferguson, Stefan Lucks, Bruce Schneier, Doug Whiting, Mihir
    Bellare, Tadayoshi Kohno, Jon Callas and Jesse Walker.
    .
    This package uses bindings to the optimized C implementation
    of Skein.  We provide a high-level interface (see module
    "Crypto.Skein") to some of the Skein use cases.  We also
    provide a low-level interface (see module
    "Crypto.Skein.Internal") should you need to use Skein in a
    different way.
    .
    Currently we have support for Skein as cryptographic hash
    function as Skein as a message authentication code
    (Skein-MAC).  For examples of how to use this package, see
    "Crypto.Skein" module documentation.
    .
    This package includes Skein v1.3. Versions of this package
    before 1.0.0 implemented Skein v1.1.
category: Cryptography
author: Felipe Lessa <felipe.lessa@gmail.com>, Doug Whiting
exposed: True
exposed-modules:
    Crypto.Skein Crypto.Skein.Internal
abi: 9d745078ae7503460b2b68669a8fbcd4
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/skein-1.0.9.4
library-dirs: /usr/lib/ghc-8.0.2/site-local/skein-1.0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/skein-1.0.9.4
hs-libraries: HSskein-1.0.9.4-GSelp4WxinFGAQx3fUyVRc
includes:
    skein.h
depends:
    base-4.9.1.0 bytestring-0.10.8.1
    cereal-0.5.4.0-KtX8p6mYm6IKYn6d7ncsjw
    crypto-api-0.13.2-6TxhqiP90JlKM4uj7GWEuA
    tagged-0.8.5-DG0qxw3gXxx4NfDcDx4Iai
haddock-interfaces: /usr/share/doc/haskell-skein/html/skein.haddock
haddock-html: /usr/share/doc/haskell-skein/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skein-1.0.9.4-11-i686.pkg.tar.xz: usr/share/haskell/register/haskell-skein.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skein
version: 1.0.9.4
id: skein-1.0.9.4-IgJQE9DOAEoCBR2BpffJio
key: skein-1.0.9.4-IgJQE9DOAEoCBR2BpffJio
license: BSD3
maintainer: Felipe Lessa <felipe.lessa@gmail.com>
homepage: https://github.com/meteficha/skein
synopsis: Skein, a family of cryptographic hash functions.  Includes Skein-MAC as well.
description:
    Skein (<http://www.skein-hash.info/>) is a family of fast
    secure cryptographic hash functions designed by Niels
    Ferguson, Stefan Lucks, Bruce Schneier, Doug Whiting, Mihir
    Bellare, Tadayoshi Kohno, Jon Callas and Jesse Walker.
    .
    This package uses bindings to the optimized C implementation
    of Skein.  We provide a high-level interface (see module
    "Crypto.Skein") to some of the Skein use cases.  We also
    provide a low-level interface (see module
    "Crypto.Skein.Internal") should you need to use Skein in a
    different way.
    .
    Currently we have support for Skein as cryptographic hash
    function as Skein as a message authentication code
    (Skein-MAC).  For examples of how to use this package, see
    "Crypto.Skein" module documentation.
    .
    This package includes Skein v1.3. Versions of this package
    before 1.0.0 implemented Skein v1.1.
category: Cryptography
author: Felipe Lessa <felipe.lessa@gmail.com>, Doug Whiting
exposed: True
indefinite: False
exposed-modules:
    Crypto.Skein Crypto.Skein.Internal
abi: 0e0dfb846120fa7a6ef1b21966b94efe
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/skein-1.0.9.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/skein-1.0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/skein-1.0.9.4
hs-libraries: HSskein-1.0.9.4-IgJQE9DOAEoCBR2BpffJio
includes:
    skein.h
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    cereal-0.5.4.0-AV9aAoAC3OtC6kJvAolohE
    tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG
    crypto-api-0.13.2-3Z9SXQnRSEg81V1yih6MCo
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             cereal-0.5.4.0-AV9aAoAC3OtC6kJvAolohE=45711223006f2eb72f62bbe45f216d21
             tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG=ef0c2166834103b504bc3792a7d2c177
             crypto-api-0.13.2-3Z9SXQnRSEg81V1yih6MCo=571c2ae2c38e25954519fd5ac2807ca5
haddock-interfaces: /usr/share/doc/haskell-skein/html/skein.haddock
haddock-html: /usr/share/doc/haskell-skein/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
